package com.sooka.sponest.mobile.aop;

import com.google.common.cache.Cache;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Objects;

/**
 * @Author 杨洺硕
 */
@Aspect
@Component
public class NoRepeatSubmitAop {
    private static final Logger log = LoggerFactory.getLogger(NoRepeatSubmitAop.class);


    @Resource
    private Cache<String, Integer> cache;

    @Around("execution(* com.sooka.sponest.mobile..*Controller.*(..)) && @annotation(nrs)")
    public Object around(ProceedingJoinPoint pjp, NoRepeatSubmit nrs) {
        try {
            ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
            String sessionId = Objects.requireNonNull(RequestContextHolder.getRequestAttributes()).getSessionId();
            HttpServletRequest request;
            if (attributes != null) {
                request = attributes.getRequest();
                String key = sessionId + "-" + request.getServletPath();
                if (cache.getIfPresent(key) == null) {
                    Object o = pjp.proceed();
                    cache.put(key, 0);
                    return o;
                } else {
                    return AjaxResult.error("抱歉，请勿重复操作");
                }
            }
        } catch (Throwable e) {
            log.error(e.getMessage());
            return AjaxResult.error("验证重复操作时出现未知异常!");
        }
        return null;
    }

}
