package com.sooka.sponest.mobile.appbigdata.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.constant.EventTypeMenuConstants;
import com.ruoyi.common.core.constant.HttpStatus;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.system.api.domain.SysMenuEventType;
import com.sooka.sponest.mobile.appbigdata.domain.CenterdataTEnvironmentRyList;
import com.sooka.sponest.mobile.appbigdata.domain.ForestCloudRYList;
import com.sooka.sponest.mobile.appbigdata.domain.bo.EnvironmentCloudRYBO;
import com.sooka.sponest.mobile.appbigdata.domain.bo.ForestCloudRYBO;
import com.sooka.sponest.mobile.appbigdata.domain.bo.VisualBO;
import com.sooka.sponest.mobile.appbigdata.domain.vo.ForestCloudMapVO;
import com.sooka.sponest.mobile.appbigdata.domain.vo.VisuForestCloudMapVO;
import com.sooka.sponest.mobile.base.service.AppAttendanceService;
import com.sooka.sponest.mobile.data.digitalagriculture.domain.VisuBaseService;
import com.sooka.sponest.mobile.remoteapi.RemoteDataBaseService;
import com.sooka.sponest.mobile.remoteapi.RemoteEventBaseService;
import com.sooka.sponest.mobile.remoteapi.RemoteMiddlewareService;
import com.sooka.sponest.mobile.remoteapi.domain.DataVO;
import com.sooka.sponest.mobile.utils.PictureReplaceAll;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;

@RestController
@RequestMapping("/AppBigDataCountController")
public class AppBigDataCountController extends VisuBaseService {

    public static final String EVENT_TYPE = "eventType";
    public static final String FOREST_EVENT_STATUS_2 = "forest_event_status_2";
    public static final String FOREST_EVENT_STATUS_5 = "forest_event_status_5";
    public static final String EVENT = "event";
    public static final String NAME_CHINESE = "name_chinese";
    public static final String NAME_ORIGINAL = "name_original";

    @Autowired
    private RemoteMiddlewareService middlewareService;
    @Autowired
    private AppAttendanceService appAttendanceService;
    @Autowired
    private RemoteEventBaseService remoteEventBaseService;
    @Autowired
    private RemoteDataBaseService dataBaseService;

    /**
     * 查询落点集合接口
     *
     * @param vb
     * @return
     */
    @PostMapping("getResourcePoint")
    public AjaxResult getResourcePoint(@RequestBody VisualBO vb) {
        R<List<DataVO>> resourcePoint = middlewareService.getResourcePoint(vb);
        if (HttpStatus.SUCCESS == resourcePoint.getCode()) {
            return AjaxResult.success(resourcePoint.getData());
        } else {
            return AjaxResult.error(resourcePoint.getMsg());
        }
    }

    /**
     * 查询落点详情接口
     * 未完成 --- 等待es编写接口后远程调用
     *
     * @return
     */
    @PostMapping("getResourceDetailById")
    public AjaxResult getResourcePointById(@RequestBody VisualBO vb) {
        R resultData = middlewareService.getResourcePointById(vb.getId(), vb.getType());
        if (HttpStatus.SUCCESS == resultData.getCode()) {
            Map<String, Object> data = (Map<String, Object>) resultData.getData();
            if (data.containsKey("pictures")) {
                List<String> pictures = (List<String>) data.get("pictures");
                if (!pictures.isEmpty()) {
                    List<String> strList = PictureReplaceAll.replacePicturesList(pictures);
                    data.put("pictures", strList);
                }
            }
            return AjaxResult.success(data);
        } else {
            return AjaxResult.error(resultData.getMsg());
        }
    }

    /**
     * 查询事件统计和资源统计接口
     *
     * @param vb
     * @return
     */
    @GetMapping("getResourceList")
    public AjaxResult getResourceList(VisualBO vb) {
        SysMenuEventType sysMenuEventType = new SysMenuEventType();
        switch (vb.getType()) {
            case "linye":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.FOREST);
                break;
            case "nongye":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.FARMING);
                break;
            case "shuili":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.WATER);
                break;
            case "huanbao":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.ENVIRONMENT);
                break;
            case "yingji":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.EMERGENCY);
                break;
            case "jiaotong":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.TRAFFIC);
                break;
            case "ziyuan":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.RESOURCES);
                break;
            case "xiaofang":
                sysMenuEventType.setMenuId(EventTypeMenuConstants.FIRECONTROL);
                break;
        }
        VisuForestCloudMapVO eventData = getEventData(sysMenuEventType);
        eventData.setDeptId(vb.getDeptId());
        Map<String, Object> map = new HashMap<>();
        map.put(EVENT, remoteEventBaseService.getEventCountGroupByEventStatus(eventData).getData());

        List<Map> dataMap = (List<Map>) middlewareService.getResourceList(vb.getAssort(), vb.getName(), vb.getType(), vb.getDeptId(), vb.getLongitude(), vb.getLatitude(), vb.getRadius()).getData();
        Iterator<Map> iterator = dataMap.iterator();
        while (iterator.hasNext()) {
            Map data = iterator.next();
            if ("centerdata_t_forest_fireteam".equals(data.get("type").toString()) && !"linye".equals(vb.getType())) {
                iterator.remove();
            } else {
                data.put(NAME_CHINESE, data.get("name").toString().split("\\(")[0] + "（" + data.get("name").toString().split("\\(")[1].split("\\)")[0] + "）");
                data.put(NAME_ORIGINAL, data.get("name").toString().split("\\(")[0]);
            }
        }
        map.put("rows", dataMap);
        return AjaxResult.success(map);
    }

    public VisuForestCloudMapVO getEventData(SysMenuEventType sysMenuEventType) {
        Map<String, String[]> stringMap = appAttendanceService.selectByMenuId(sysMenuEventType).getData();
        VisuForestCloudMapVO visuForestCloudMapVO = new VisuForestCloudMapVO();
        visuForestCloudMapVO.setEventTypeId(stringMap.get(EVENT_TYPE));
        List<String> list = new ArrayList<>();
        list.add(FOREST_EVENT_STATUS_2);
        list.add(FOREST_EVENT_STATUS_5);
        visuForestCloudMapVO.setEventStatus(list);
        return visuForestCloudMapVO;
    }

    /******************************************************************************************************************************************************/
    public JSONArray typeUnity(ArrayList<?> list) {
        JSONArray result = new JSONArray();
        for (Object data : list) {
            JSONObject jsonObject = (JSONObject) JSONObject.toJSON(data);
            if (jsonObject.containsKey("dictType")) {
                jsonObject.put("jobValue", jsonObject.remove("dictType"));
            }
            result.add(jsonObject);
        }
        return result;
    }

    /**
     * @throws
     * @description
     * @author LG
     * @param[1] deptId
     * @param[2] leadType
     * @Api 河长，路长，田长，获取人员类型
     * @time 2023/8/16 18:29
     */
    private ArrayList<Map<String, Object>> getRyListByJob(Long deptId, String leadType) {
        AjaxResult waterResult = dataBaseService.getRyListToWaterConservancyViewByType(deptId, leadType);
        LinkedHashMap<String, Object> data = (LinkedHashMap<String, Object>) waterResult.get("data");
        return (ArrayList<Map<String, Object>>) data.get("ryList");
    }

    /**
     * 获取航管局对应的人员类型
     *
     * @param dictValue 行管局类型 1：林业；2：农业；3：水利；4：环保；5：应急；6：交通；7：资源；8：消防
     * @param deptId    部门id
     * @param leadType  人员类型
     * @return AjaxResult
     */
    @GetMapping("/getPersonTypeBySystem")
    public AjaxResult getPersonTypeBySystem(String dictValue, Long deptId, String leadType) {
        ForestCloudMapVO forestMapVo = new ForestCloudMapVO();
        forestMapVo.setDeptId(deptId);
        switch (dictValue) {
            case "1"://林业
                R<ForestCloudRYList> ryListToForestView = dataBaseService.getRyListToForestView(forestMapVo);
                if (HttpStatus.SUCCESS == ryListToForestView.getCode()) {
                    ArrayList<ForestCloudRYBO> visuForestCloudRYBO = (ArrayList<ForestCloudRYBO>) ryListToForestView.getData().getVisuForestCloudRYBO();
                    return AjaxResult.success(typeUnity(visuForestCloudRYBO));
                } else {
                    return AjaxResult.error(ryListToForestView.getCode(), ryListToForestView.getMsg());
                }
            case "2"://农业
                //无
                return AjaxResult.success(new JSONArray());
            case "3"://水利
                return AjaxResult.success(typeUnity(getRyListByJob(deptId, leadType)));
            case "4"://环保
                R<CenterdataTEnvironmentRyList> ryListToEnvironmentView = dataBaseService.getRyListToEnvironmentView(forestMapVo);
                if (HttpStatus.SUCCESS == ryListToEnvironmentView.getCode()) {
                    ArrayList<EnvironmentCloudRYBO> userList = (ArrayList<EnvironmentCloudRYBO>) ryListToEnvironmentView.getData().getUser();
                    return AjaxResult.success(typeUnity(userList));
                } else {
                    return AjaxResult.error(ryListToEnvironmentView.getCode(), ryListToEnvironmentView.getMsg());
                }
            case "5"://应急
                return AjaxResult.success(new JSONArray());
            case "6"://交通
                return AjaxResult.success(typeUnity(getRyListByJob(deptId, leadType)));
            case "7"://资源
                return AjaxResult.success(typeUnity(getRyListByJob(deptId, leadType)));
            case "8"://消防
                R<Map<String, Object>> ryListToFireControlView = dataBaseService.getRyListToFireControlView(deptId);
                if (HttpStatus.SUCCESS == ryListToFireControlView.getCode()) {
                    ArrayList<Map<String, Object>> fireControlList = (ArrayList<Map<String, Object>>) ryListToFireControlView.getData().get("ryList");
                    return AjaxResult.success(typeUnity(fireControlList));
                } else {
                    return AjaxResult.error(ryListToFireControlView.getCode(), ryListToFireControlView.getMsg());
                }
            default: {
                return AjaxResult.error(500, "航管局类型错误");
            }
        }
    }
}
