package com.sooka.sponest.mobile.data.digitalenvironmentcontroller;

import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.PageDomain;
import com.ruoyi.common.core.web.page.TableSupport;
import com.sooka.sponest.data.api.digitalenvironment.domain.EnvironmentSourcePollution;
import com.sooka.sponest.data.api.digitalenvironment.service.RemoteSourcePollutionService;
import com.sooka.sponest.mobile.system.camera.service.AppCameraService;
import com.sooka.sponest.mobile.utils.PictureReplaceAll;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * 污染源管理Controller
 *
 * @author lyq
 * @date 2022-11-01
 */

@RestController
@RequestMapping("/AppPollutionSourceController")
public class PollutionSourceController extends BaseController {

    @Autowired
    private RemoteSourcePollutionService pollutionSourceService;

    @Resource
    AppCameraService appCameraService;

    /**
     * 查询污染源管理列表
     */
    @GetMapping("/pollutionSource/list")
    public AjaxResult list(EnvironmentSourcePollution environmentSourcePollution) {
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        String name = environmentSourcePollution.getName();
        String address = environmentSourcePollution.getAddress();
        Long type = environmentSourcePollution.getType();
        return AjaxResult.success(pollutionSourceService.pollutionSourceList(pageNum, pageSize, name, address, type).getRows());
    }


    /**
     * 获取污染源管理详细信息
     */
    @GetMapping("/pollutionSource/edit")
    public AjaxResult getInfo(EnvironmentSourcePollution environmentSourcePollution) {
        AjaxResult ajaxResult = pollutionSourceService.pollutionSourceGetInfo(environmentSourcePollution.getId());
        if("200".equals(ajaxResult.get("code").toString())){
            Map<String, Object> info = (Map<String, Object>) ajaxResult.get("data");
            PictureReplaceAll.StringToList(info);
            return appCameraService.selectCameraByIds(info);
        }else{
            return ajaxResult;
        }
    }

    /**
     * 新增污染源管理
     */
    @PostMapping("/pollutionSource")
    public AjaxResult add(@RequestBody String json) {
        return pollutionSourceService.pollutionSourceAdd(json);
    }

    /**
     * 修改污染源管理
     */
    @PostMapping("/pollutionSource/put")
    public AjaxResult edit(@RequestBody String json) {
        return pollutionSourceService.pollutionSourceEdit(json);
    }

    /**
     * 删除污染源管理
     */
    @GetMapping("/pollutionSource/del")
    public AjaxResult remove(@RequestParam("id") List<String> id) {
        return pollutionSourceService.pollutionSourceRemove(id.toArray(new String[0]));
    }

}
