package com.sooka.sponest.mobile.data.digitaltrafficcontroller;

import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.PageDomain;
import com.ruoyi.common.core.web.page.TableSupport;
import com.sooka.sponest.data.api.digitaltraffic.domain.Bridge;
import com.sooka.sponest.data.api.digitaltraffic.servce.RemoteBridgeService;
import com.sooka.sponest.mobile.system.camera.service.AppCameraService;
import com.sooka.sponest.mobile.utils.PictureReplaceAll;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 桥梁资源Controller
 *
 * @author lyq
 * @date 2022-11-17
 */
@Api(tags = "桥梁资源控制器")
@RestController
@RequestMapping("/AppBridgeController")
public class BridgeController extends BaseController {

    @Autowired
    private RemoteBridgeService bridgeService;

    @Resource
    AppCameraService appCameraService;

    /**
     * 查询桥梁资源列表
     */
    @GetMapping("/bridge/list")
    public AjaxResult list(Bridge bridge) {
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        String name = bridge.getName();
        return AjaxResult.success(bridgeService.bridgeList(pageNum, pageSize, name).getRows());
    }


    /**
     * 获取桥梁资源详细信息
     */
    @GetMapping("/bridge/edit")
    public AjaxResult getInfo(Bridge bridge) {
        AjaxResult ajaxResult = bridgeService.bridgeGetInfo(bridge.getId());
        if("200".equals(ajaxResult.get("code").toString())){
            Map<String, Object> info = (Map<String, Object>) ajaxResult.get("data");
            PictureReplaceAll.StringToList(info);
            return appCameraService.selectCameraByIds(info);
        }else{
            return ajaxResult;
        }
    }

    /**
     * 新增桥梁资源
     */
    @PostMapping( "/bridge")
    public AjaxResult add(@RequestBody String json) {
        return bridgeService.bridgeAdd(json);
    }

    /**
     * 修改桥梁资源
     */
    @PostMapping("/bridge/put")
    public AjaxResult edit(@RequestBody String json) {

        return bridgeService.bridgeEdit(json);
    }

    /**
     * 删除桥梁资源
     */
    @GetMapping("/bridge/del")
    public AjaxResult remove(@RequestParam("id") List<String> id) {
        return bridgeService.bridgeRemove(id.toArray(new String[0]));
    }
}
