package com.sooka.sponest.mobile.data.digitaltrafficcontroller;

import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.PageDomain;
import com.ruoyi.common.core.web.page.TableSupport;
import com.sooka.sponest.data.api.digitaltraffic.domain.Culvert;
import com.sooka.sponest.data.api.digitaltraffic.servce.RemoteCulvertService;
import com.sooka.sponest.mobile.system.camera.service.AppCameraService;
import com.sooka.sponest.mobile.utils.PictureReplaceAll;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * 涵洞资源Controller
 *
 * @author lyq
 * @date 2022-11-17
 */
@Api(tags = "涵洞资源控制器")
@RestController
@RequestMapping("/AppCulvertController")
public class CulvertController extends BaseController {

    @Autowired
    private RemoteCulvertService digITaltrafficService;

    @Resource
    AppCameraService appCameraService;

    /**
     * 查询涵洞资源列表
     */
    @GetMapping("/culvert/list")
    public AjaxResult list(Culvert culvert) {
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        String name = culvert.getName();
        return AjaxResult.success(digITaltrafficService.culvertList(pageNum, pageSize, name).getRows());
    }

    /**
     * 获取涵洞资源详细信息
     */
    @GetMapping(value = "/culvert/edit")
    public AjaxResult getInfo(Culvert culvert) {
        AjaxResult ajaxResult = digITaltrafficService.culvertGetInfo(culvert.getId());
        if("200".equals(ajaxResult.get("code").toString())){
            Map<String, Object> info = (Map<String, Object>) ajaxResult.get("data");
            PictureReplaceAll.StringToList(info);
            return appCameraService.selectCameraByIds(info);
        }else{
            return ajaxResult;
        }
    }

    /**
     * 新增涵洞资源
     */
    @PostMapping("/culvert")
    public AjaxResult add(@RequestBody String json) {
        return digITaltrafficService.culvertAdd(json);
    }

    /**
     * 修改涵洞资源
     */
    @PostMapping("/culvert/put")
    public AjaxResult edit(@RequestBody String json) {
        return digITaltrafficService.culvertEdit(json);
    }

    /**
     * 删除涵洞资源
     */
    @GetMapping("/culvert/del")
    public AjaxResult remove(@RequestParam("id") List<String> id) {
        return digITaltrafficService.culvertRemove(id.toArray(new String[0]));
    }
}
