package com.sooka.sponest.mobile.data.generalbusiness;

import com.ruoyi.common.core.constant.HttpStatus;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.sooka.sponest.data.api.generalbusiness.domain.AppFileVO;
import com.sooka.sponest.data.api.generalbusiness.domain.SysFile;
import com.sooka.sponest.data.api.generalbusiness.service.RemoteFileBaseService;
import com.sooka.sponest.data.api.generalbusiness.service.RemoteGeneralbusinessService;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.BufferedOutputStream;
import java.io.OutputStream;
import java.net.URLEncoder;

@RestController
@RequestMapping("AppFileController")
public class AppFileController {
    Logger logger = LoggerFactory.getLogger(this.getClass());

    @Resource
    RemoteFileBaseService remoteFileBaseService;

    @Resource
    RemoteGeneralbusinessService remoteDataBaseService;

    /**
     * 手机端专用上传
     */
    @ApiOperation(value = "手机端专用上传", notes = "手机端专用上传")
    @PostMapping("/appUpload")
    public AjaxResult appUpload(MultipartFile file){
        R<SysFile> sysFileR = remoteFileBaseService.appUpload(file);
        if(HttpStatus.SUCCESS == sysFileR.getCode()){
            return AjaxResult.success(sysFileR.getData());
        }else{
            return AjaxResult.error(sysFileR.getCode(),sysFileR.getMsg());
        }

    }

    /**
     * 手机端专用下载
     */
    @ApiOperation(value = "手机端专用下载", notes = "手机端专用下载")
    @GetMapping("/appDownload")
    public void appDownload(HttpServletResponse response, String fileName,String group,String path){
        try {
            byte[] b = remoteFileBaseService.appDownload(group,path).getData();
            // 清空response
            response.reset();
            // 设置response的Header
            response.setContentType("application/octet-stream;charset=utf-8");
            fileName = URLEncoder.encode(fileName,"UTF-8");
            response.setHeader("Content-Disposition", "attachment;filename=" + fileName);
            OutputStream toClient = new BufferedOutputStream(response.getOutputStream());
            toClient.write(b);
            toClient.flush();
            toClient.close();
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
    }



    /**
     * 文件管理列表
     *
     * @param vo
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 14:41
     **/
    @ApiOperation(value = "列表目录", notes = "列表目录")
    @GetMapping("listDir")
    public AjaxResult listDir(AppFileVO vo) {
        Long dataDeptId = vo.getDeptId();
        String type = "1";
        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("data", remoteDataBaseService.listappFile(dataDeptId, type, vo.getPageSize(), vo.getPageNum()));
        ajaxResult.put("code", 200);
        return ajaxResult;

    }

    @ApiOperation(value = "列表文件", notes = "列表文件")
    @GetMapping("listFiles")
    public AjaxResult listFiles(AppFileVO vo) {
        String parentId = vo.getDirId();
        String name = vo.getSuffix();
        String type = "2";
        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("data", remoteDataBaseService.listappFilelike(parentId, name, type));
        ajaxResult.put("code", 200);
        return ajaxResult;
    }
}
