package com.sooka.sponest.mobile.data.generalbusiness.service.impl;

import com.ruoyi.common.core.web.domain.AjaxResult;
import com.sooka.sponest.mobile.data.generalbusiness.domain.AppDailyBO;
import com.sooka.sponest.mobile.data.generalbusiness.domain.AppDailyVO;
import com.sooka.sponest.mobile.data.generalbusiness.service.AppDailyService;
import com.sooka.sponest.mobile.remoteapi.RemoteDataBaseService;
import org.apache.http.client.utils.DateUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

@Service
public class AppDailyServiceImpl implements AppDailyService {
    private static final Logger log = LoggerFactory.getLogger(AppDailyServiceImpl.class);


    @Resource
    RemoteDataBaseService remoteDataBaseService;

    /**
     * 手机端添加日报
     *
     * @param appDailyVO
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 9:10
     */
    @Override
    public AjaxResult addDaily(AppDailyVO appDailyVO) {
        try {
            AppDailyBO bo = new AppDailyBO();
            bo.setCreateBy(appDailyVO.getCreateBy());
            String today = DateUtils.formatDate(appDailyVO.getCreateTime());
            bo.setDeptName(today);
            Integer i = 0;
            Integer repeatDaily = remoteDataBaseService.selectRepeatDaily(bo).getData();
            if (i.equals(repeatDaily)) {
//                bo.setCreateTime(DateUtils.getNowDate());
                bo.setDeptId(appDailyVO.getDataDeptId());
                bo.setDeptName(appDailyVO.getDataDeptName());
                bo.setDailyTitle(appDailyVO.getDailyTitle());
                bo.setDailyContent(appDailyVO.getDailyContent());
                bo.setDailyTime(appDailyVO.getCreateTime());
                remoteDataBaseService.addDaily(bo);
                return AjaxResult.success("添加成功");
            }
            return AjaxResult.error("当天已添加,勿重复提交");
        } catch (Exception e) {
            log.error(e.getMessage());
            return AjaxResult.error("添加失败");
        }
    }

    /**
     * 手机端查询本人-本月 日报情况
     *
     * @param appDailyVO
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 14:30
     **/
    @Override
    public AjaxResult queryDailyByMonth(AppDailyVO appDailyVO) {
        try {

            List<AppDailyBO> list = remoteDataBaseService.queryDailyByMonth(appDailyVO).getData();
            return AjaxResult.success(list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return AjaxResult.error("查询失败");
        }
    }

    /**
     * 手机端查询本人-指定日期 日报情况
     *
     * @param appDailyVO
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 9:11
     */
    @Override
    public AjaxResult queryDailyByDay(AppDailyVO appDailyVO) {
        try {
            AppDailyBO bo = remoteDataBaseService.queryDailyByDay(appDailyVO).getData();
            if (null != bo) {
                return AjaxResult.success(bo);
            } else {
                AppDailyBO dauliy = new AppDailyBO();
                return AjaxResult.success(dauliy);
            }
        } catch (Exception e) {
            log.error(e.getMessage());
            return AjaxResult.error("查询失败");
        }

    }


}
