package com.sooka.sponest.mobile.event.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.domain.SysDept;
import com.sooka.sponest.mobile.aop.NoRepeatSubmit;
import com.sooka.sponest.mobile.base.controller.AppBaseController;
import com.sooka.sponest.mobile.event.domain.*;
import com.sooka.sponest.mobile.event.service.AppEventService;
import com.sooka.sponest.mobile.remoteapi.*;
import com.sooka.sponest.mobile.remoteapi.domain.CentereventtDeptEventBO;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

@RequestMapping("AppEventController")
@RestController
public class AppEventController extends AppBaseController {

    @Resource
    AppEventService appEventService;

    @Resource
    RemoteCenterBaseService remoteCenterBaseService;
    @Resource
    RemoteTaskBaseService remoteTaskBaseService;

    @Resource
    RemoteEventBaseService remoteEventBaseService;

    @Resource
    RemoteMessageBaseService remoteMessageBaseService;

    @Resource
    RemoteSystemBaseService remoteSystemBaseService;


    /**
     * 手机查询大类小类(上报时使用)
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/23 9:09
     */
    @ApiOperation(value = "手机查询大类小类", notes = "手机查询大类小类")
    @GetMapping("listSJfl")
    public AjaxResult listSJfl(String parentId) {
        return remoteCenterBaseService.listSJfl(parentId);
    }


    /**
     * 手机查询行管局
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/23 9:09
     */
    @ApiOperation(value = "查询行管局", notes = "查询行管局")
    @GetMapping("listHgjXl")
    public AjaxResult listHgjXl(String eventTypeValue) {
        return remoteCenterBaseService.listHgjXl(eventTypeValue);
    }

    /**
     * 手机上报事件
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/23 9:09
     */
    @ApiOperation(value = "手机上报事件", notes = "手机上报事件")
    @NoRepeatSubmit
    @PostMapping("addEventFen")
    public AjaxResult addEventFen(@RequestBody AppCentereventTEventcatalogueVO vo) {
        return AjaxResult.success(remoteCenterBaseService.addOpenFen(vo));
    }

    /**
     * 手机端事件列表
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/21 15:31
     */
    @ApiOperation(value = "事件列表", notes = "事件列表")
    @GetMapping("eventFindAll")
    public R<List<AppEventSalBO>> eventFindAll(AppEventSalVO vo) {
        return appEventService.eventFindAll(vo);
    }


    /**
     * 手机端获取事件大小类(查询时使用)
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/21 13:37
     */
    @ApiOperation(value = "手机端获取事件大小类", notes = "手机端获取事件大小类")
    @GetMapping("queryEventBySelect")
    public AjaxResult queryEventBySelect() {
        return AjaxResult.success(appEventService.queryEventBySelect());
    }


    /**
     * 手机端查看事件详情
     *
     * @param code
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/21 13:51
     */
    @ApiOperation(value = "手机端查看事件详情", notes = "手机端查看事件详情")
    @GetMapping("queryEventDetail")
    public AjaxResult queryEventDetail(String code) {
        return appEventService.queryEventDetail(code);
    }

    /**
     * 反馈列表
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 13:57
     */
    @ApiOperation(value = "反馈列表", notes = "反馈列表")
    @GetMapping("eventLogList")
    public AjaxResult eventLogList(String pageNum, String pageSize, String eventCode) {
        return remoteCenterBaseService.eventLogList(pageNum, pageSize, eventCode);
    }

    @ApiOperation(value = "反馈列表", notes = "反馈列表")
    @GetMapping("eventLogListAllAndDetails")
    public AjaxResult eventLogListAllAndDetails(String eventCode) {
        AjaxResult ajaxResult = remoteCenterBaseService.eventLogListAll(eventCode);
        ArrayList<HashMap<String, Object>> result = (ArrayList<HashMap<String, Object>>) ajaxResult.get("data");
        for (HashMap<String, Object> map : result) {
            AjaxResult ajaxResult1 = appEventService.selectCentereventTFireLogById(map.get("id").toString());
            CentereventTFireLog data = (CentereventTFireLog) ajaxResult1.get("data");
            map.put("attachs", data.getAttachs());
            map.put("attachsMp", data.getAttachsMp());
        }
        return ajaxResult;
    }


    /**
     * 反馈上报
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 13:57
     */
    @ApiOperation(value = "反馈上报", notes = "反馈上报")
    @NoRepeatSubmit
    @PostMapping("eventLogAdd")
    public AjaxResult eventLogAdd(@RequestBody CentereventTFireLog centereventTFireLog) {
        return remoteCenterBaseService.eventLogAdd(centereventTFireLog);
    }


    /**
     * 修改事件状态
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 13:46
     */
    @ApiOperation(value = "修改状态", notes = "修改状态")
    @NoRepeatSubmit
    @PostMapping("EventFeignedit")
    public R EventFeignedit(@RequestBody CentereventtDeptEventBO centereventtDeptEventBO) {
        return remoteCenterBaseService.EventFeignedit(centereventtDeptEventBO);
    }

    @ApiOperation(value = "查询事件部门信息", notes = "查询事件部门信息")
    @PostMapping("/centereventtdepteventList")
    public AjaxResult centereventtdepteventList(@RequestBody CentereventDeptEvent centereventTDeptEvent) {
        return AjaxResult.success(remoteCenterBaseService.remotecentereventtdepteventList(centereventTDeptEvent.getEventCode()).getData());
    }

    /**
     * 获取用户部门列表
     */
    @ApiOperation(value = "远程获取用户部门列表", notes = "远程获取用户列表")
    @GetMapping("/selectUserWithPostByDeptId")
    public AjaxResult selectUserWithPostByDeptId(SysUserSystem sysUserSystem) {
        List<SysUserSystem> list = remoteSystemBaseService.selectUserWithPostByDeptId(sysUserSystem.getDeptId()).getData();
        return AjaxResult.success(list);
    }

    @ApiOperation(value = "发送会议短信", notes = "发送会议短信")
    @PostMapping("/sendMeetingMsg")
    public AjaxResult sendMeetingMsg(@RequestBody CentereventMeetingSystemBO centereventMeetingSystemBO) {
        AjaxResult result = remoteSystemBaseService.joinConferences(centereventMeetingSystemBO.getEventId(), centereventMeetingSystemBO.getMeetingSubject(), centereventMeetingSystemBO.getUserName());
        if (!result.get("code").equals(200)) {
            return AjaxResult.error("查询失败");
        } else {
            List<CentereventTDutySystemBO> meetingSystemList = centereventMeetingSystemBO.getCentereventTDutySystemList();
            meetingSystemList.forEach(e -> {
                e.setPost(e.getPostName());
                e.setTelphone(e.getPhonenumber());
            });
            return AjaxResult.success(remoteMessageBaseService.remoteSendMeetingMsg(centereventMeetingSystemBO).getData());
        }
    }


    /**
     * 反馈详情
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 14:00
     */
    @ApiOperation(value = "反馈详情", notes = "反馈详情")
    @GetMapping("EventFeignGetInfo")
    public AjaxResult EventFeignGetInfo(String id) {
        return appEventService.selectCentereventTFireLogById(id);
    }


    /**
     * 任务列表
     *
     * @return 待领取
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 14:52111
     */
    @ApiOperation(value = "任务列表", notes = "任务列表")
    @PostMapping("taskList")
    public AjaxResult taskList() {
        CenterTaskSelectTaskVO vo = new CenterTaskSelectTaskVO();
        vo.setDepts(SecurityUtils.getLoginUser().getSysUser().getDepts());
        List<CenterTaskSelectTaskBO> data = (List<CenterTaskSelectTaskBO>) remoteTaskBaseService.selectUnclaimedTaskBO(vo).getData();
        return AjaxResult.success(data);

    }

    /**
     * 手机端查询任务部门
     *
     * @param vo
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 15:00
     **/
    @ApiOperation(value = "查询任务部门", notes = "查询任务部门")
    @PostMapping("selectTaskDtpts")
    public AjaxResult selectTaskDtpts(@RequestBody CenterTaskTaskDeptVO vo) {
        vo.setDepts(SecurityUtils.getLoginUser().getSysUser().getDepts());
        return AjaxResult.success(remoteTaskBaseService.selectTaskDtpts(vo).getData());
    }


    /**
     * 手机端领取任务
     *
     * @param receiveTaskVO
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 15:03
     **/
    @ApiOperation(value = "领取任务", notes = "领取任务")
    @PostMapping("receiveTask")
    public AjaxResult receiveTask(@RequestBody ReceiveTaskVO receiveTaskVO) {
        receiveTaskVO.setReceiverId(SecurityUtils.getLoginUser().getSysUser().getUserId());
        receiveTaskVO.setReceiverName(SecurityUtils.getLoginUser().getSysUser().getNickName());

        CentereventTFireLog centereventTFireLog = new CentereventTFireLog();
        centereventTFireLog.setId(IdUtils.fastSimpleUUID());
        centereventTFireLog.setEventCode(receiveTaskVO.getEventCode());
        String logDept = "";
        List<SysDept> listDept = SecurityUtils.getLoginUser().getSysUser().getDepts();
        for (SysDept sysDept : listDept) {
            logDept += sysDept.getDeptName() + ",";
        }
        centereventTFireLog.setOperationType("log_oper_type_1");
        centereventTFireLog.setOperation("bus_oper_type_2");
        centereventTFireLog.setCreateBy(SecurityUtils.getLoginUser().getUserid().toString());
        centereventTFireLog.setCreateName(SecurityUtils.getLoginUser().getSysUser().getNickName());
        centereventTFireLog.setLogContent(SecurityUtils.getLoginUser().getSysUser().getNickName() + "领取任务，领取部门为" + logDept);
        remoteCenterBaseService.add(centereventTFireLog);
        String msg = (String) remoteTaskBaseService.receiveTask(receiveTaskVO).get("msg");
        if ("操作成功".equals(msg)) {
            for (SysDept sysDept : listDept) {
                CentereventDeptEvent centereventDeptEvent = new CentereventDeptEvent();
                centereventDeptEvent.setId(IdUtils.fastSimpleUUID());
                centereventDeptEvent.setDeptId(sysDept.getDeptId());
                centereventDeptEvent.setDeptName(sysDept.getDeptName());
                centereventDeptEvent.setEventCode(receiveTaskVO.getEventCode());
                centereventDeptEvent.setEventStatus("签收");
                centereventDeptEvent.setIsUrged("sys_isurge_1");
                centereventDeptEvent.setUrgeType("event_urge_1");
                centereventDeptEvent.setEventStatusValue("forest_event_status_2");
                centereventDeptEvent.setDeptHandleType("dept_handleType_2");
                remoteEventBaseService.remoteAdd(centereventDeptEvent);
            }
        }
        return AjaxResult.success(msg, "");
    }


    /**
     * 手机端拒绝任务
     *
     * @param refusedTaskVO
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 15:03
     **/
    @ApiOperation(value = "拒绝任务", notes = "拒绝任务")
    @PostMapping("refusedTask")
    public AjaxResult refusedTask(@RequestBody RefusedTaskVO refusedTaskVO) {
        CentereventTFireLog centereventTFireLog = new CentereventTFireLog();
        centereventTFireLog.setId(IdUtils.fastSimpleUUID());
        centereventTFireLog.setEventCode(refusedTaskVO.getEventCode());

        centereventTFireLog.setOperationType("log_oper_type_1");
        centereventTFireLog.setOperation("bus_oper_type_2");
        centereventTFireLog.setCreateBy(SecurityUtils.getLoginUser().getUserid().toString());
        centereventTFireLog.setCreateName(SecurityUtils.getLoginUser().getSysUser().getNickName());
        centereventTFireLog.setLogContent(SecurityUtils.getLoginUser().getSysUser().getNickName() + "拒绝领取任务");
        remoteCenterBaseService.add(centereventTFireLog);
        String msg = (String) remoteTaskBaseService.refusedTask(refusedTaskVO).get("msg");
        return AjaxResult.success(msg, "");
    }

    /**
     * 根据事件编码查询事件部门信息
     *
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 15:03
     **/
    @GetMapping("selectByeventCodeFeign")
    public AjaxResult selectByeventCodeFeign(String eventCode) {
        return AjaxResult.success(remoteCenterBaseService.selectByeventCodeFeign(eventCode).get("data"));
    }

    /**
     * 手机端任务列表查找全部
     * 已领取
     *
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 13:35
     **/
    @ApiOperation(value = "任务列表查找全部", notes = "任务列表查找全部")
    @PostMapping("taskListFindAll")
    public AjaxResult taskListFindAll() {
        CenterTaskSelectTaskVO vo = new CenterTaskSelectTaskVO();
        SysDept dept = new SysDept();
        dept.setDeptId(SecurityUtils.getLoginUser().getSysUser().getDeptId());
        List<SysDept> list = new ArrayList<>();
        list.add(dept);
        vo.setDepts(list);
        List<CenterTaskAppTaskBO> data = (List<CenterTaskAppTaskBO>) remoteTaskBaseService.selectReceivedTaskBO(vo).getData();
        return AjaxResult.success(data);

    }

}
