package com.sooka.sponest.mobile.event.service.impl;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.file.FilePrefixUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.sooka.sponest.mobile.event.domain.*;
import com.sooka.sponest.mobile.event.service.AppEventService;
import com.sooka.sponest.mobile.remoteapi.RemoteDataBaseService;
import com.sooka.sponest.mobile.remoteapi.RemoteEventBaseService;
import com.sooka.sponest.mobile.remoteapi.RemoteMonitorBaseService;
import com.sooka.sponest.mobile.remoteapi.RemoteSystemBaseService;
import org.apache.commons.collections4.MapUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

@Service
public class AppEventServiceImpl implements AppEventService {

    private static final Logger log = LoggerFactory.getLogger(AppEventServiceImpl.class);

    @Resource
    RemoteSystemBaseService remoteSystemBaseService;

    @Resource
    RemoteDataBaseService remoteDataBaseService;

    @Resource
    RemoteEventBaseService remoteEventBaseService;

    /**
     * 手机端事件列表
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/21 15:31
     */
    @Override
    public R<List<AppEventSalBO>> eventFindAll(AppEventSalVO vo) {
        return remoteEventBaseService.listByApp(vo);
    }


    /**
     * 手机端获取事件大小类
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/21 13:37
     */
    @Override
    public List<AppEventTypeBO> queryEventBySelect() {
        List<AppEventTypeBO> list = remoteEventBaseService.getCentereventTEventtypeByParentId(null).getData();
        return queryEventSonBySelect(list, "0");
    }

    /**
     * 手机端获取事件大小类解析数据内部方法
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/21 13:37
     */
    @Override
    public List<AppEventTypeBO> queryEventSonBySelect(List<AppEventTypeBO> list, String id) {
        List<AppEventTypeBO> bo = new ArrayList<>();
        for (int i = 0; i < list.size(); i++) {
            if (list.get(i).getParentId().equals(id)) {
                AppEventTypeBO mt = list.get(i);
                mt.setChildren(queryEventSonBySelect(list, list.get(i).getId()));
                bo.add(mt);
            }
        }
        return bo;
    }

    /**
     * 手机端查看事件详情
     *
     * @param eventCode
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/21 13:51
     */
    @Override
    public AjaxResult queryEventDetail(String eventCode) {
        try {
            AppEventSalBO appEventSalBO = remoteEventBaseService.getCentereventTEventcatalogueByCode(eventCode).getData();
            String token = "";// 大华token
            if (dahuaFile) {
                token = remoteMonitorService.getToken();
            }
            Map<String, String> keyMap = remoteSystemBaseService.remotegetConfigMap(Arrays.asList("downloadUrl", "appUrl", "HIK_1", "HIK_2", "DH_1", "DH_2")).getData();
            String finalToken = token;
            appEventSalBO.getAttachs().forEach(item -> {
                String urlPrefix = FilePrefixUtils.getAPPUrlPrefix(item.getBusSource(), keyMap);
                if ("DH_1".equals(item.getBusSource())) {
                    item.setAttachPath(DH1 + item.getAttachPath() + "?token=" + finalToken);
                } else if ("DH_2".equals(item.getBusSource())) {
                    item.setAttachPath(DH2 + item.getAttachPath());
                } else {
                    item.setAttachPath(urlPrefix + item.getAttachPath());
                }
            });
//            appEventSalBO.getAttachsMpf().forEach(item -> item.setAttachPath(MapUtils.getString(keyMap, "appUrl") + item.getAttachPath()));
            appEventSalBO.getAttachsMpf().forEach(item -> {
                if (!"TT_1".equals(item.getBusSource())) {
                    item.setAttachPath(MapUtils.getString(keyMap, "appUrl") + item.getAttachPath());
                }
            });
            return AjaxResult.success(appEventSalBO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return AjaxResult.error("查询失败");
        }
    }

    @Value("${sooka.dahuafile:}")
    private Boolean dahuaFile;

    @Value("${sooka.DH1:}")
    private String DH1;

    @Value("${sooka.DH2:}")
    private String DH2;

    @Autowired
    private RemoteMonitorBaseService remoteMonitorService;

    /**
     * 反馈详情
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 14:00
     */
    @Override
    public AjaxResult selectCentereventTFireLogById(String id) {
        CentereventTFireLog log = remoteEventBaseService.selectCentereventTFireLogById(id).getData();
        log.setWebUrl("");
        List<AppDataTAttach> appDataTAttachList = remoteDataBaseService.attachBFireLogById(id).getData();
        Map<String, String> keyMap = remoteSystemBaseService.remotegetConfigMap(Arrays.asList("downloadUrl", "appUrl", "HIK_1", "HIK_2", "DH_1", "DH_2")).getData();
        String token = "";// 大华token
        if (dahuaFile) {
            token = remoteMonitorService.getToken();
        }
        for (AppDataTAttach appDataTAttach : appDataTAttachList) {
            String urlPrefix = FilePrefixUtils.getAPPUrlPrefix(appDataTAttach.getBusSource(), keyMap);
            if ("DH_1".equals(appDataTAttach.getBusSource())) {
                appDataTAttach.setAttachPath(DH1 + appDataTAttach.getAttachPath() + "?token=" + token);
            } else if ("DH_2".equals(appDataTAttach.getBusSource())) {
                appDataTAttach.setAttachPath(DH2 + appDataTAttach.getAttachPath());
            } else if ("TT_1".equals(appDataTAttach.getBusSource())) {

            } else if (appDataTAttach.getAttachPath().endsWith(".jpg") || appDataTAttach.getAttachPath().endsWith(".gif") || appDataTAttach.getAttachPath().endsWith(".png")
                    || appDataTAttach.getAttachPath().endsWith(".jpeg") || appDataTAttach.getAttachPath().endsWith(".bmp") || appDataTAttach.getAttachPath().endsWith(".webp")
                    || appDataTAttach.getAttachPath().endsWith(".psd") || appDataTAttach.getAttachPath().endsWith(".svg") || appDataTAttach.getAttachPath().endsWith(".tiff")
                    || appDataTAttach.getAttachPath().endsWith(".mp4")) {
                appDataTAttach.setAttachPath(urlPrefix + appDataTAttach.getAttachPath());
            } else {
                StringBuilder newDiles = new StringBuilder();
                String url = appDataTAttach.getAttachPath();
                String name = appDataTAttach.getFileName();
                newDiles.append(keyMap.get("downloadUrl") + "Download?fileName=" + name + "&&group=" + url.substring(0, url.indexOf('/')) + "&&path=" + url.substring(url.indexOf('/') + 1));
                appDataTAttach.setAttachPath(newDiles.toString());
            }
        }
        log.setAttachs(appDataTAttachList);
        List<AppDataTAttach> appDataTAttachList1 = remoteDataBaseService.attachBFireLogByIdMp(id).getData();
        for (AppDataTAttach appDataTAttach : appDataTAttachList1) {
            String urlPrefix = FilePrefixUtils.getAPPUrlPrefix(appDataTAttach.getBusSource(), keyMap);
            appDataTAttach.setAttachPath(urlPrefix + appDataTAttach.getAttachPath());
        }
        log.setAttachsMp(appDataTAttachList1);
        return AjaxResult.success(log);
    }
}
