package com.sooka.sponest.mobile.remoteapi;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.constant.SecurityConstants;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.api.domain.SysDept;
import com.ruoyi.system.api.domain.SysMenuEventType;
import com.ruoyi.system.api.domain.SysUser;
import com.ruoyi.system.api.model.LoginUser;
import com.sooka.sponest.mobile.base.domain.ModulesServiceNameContants;
import com.sooka.sponest.mobile.base.domain.SysAttendance;
import com.sooka.sponest.mobile.event.domain.SysUserSystem;
import com.sooka.sponest.mobile.log.LogFeignCall;
import com.sooka.sponest.mobile.remoteapi.factory.RemoteSystemBaseServiceFallbackFactory;
import com.sooka.sponest.mobile.system.login.domain.AppUpPwd;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@FeignClient(contextId = "remoteSystemService", value = ModulesServiceNameContants.SYSTEM_SERVICE,
        fallbackFactory = RemoteSystemBaseServiceFallbackFactory.class, url = "${sooka.service.system}")
public interface RemoteSystemBaseService {

    /**
     * 查询轮播图列表(无参)
     *
     * @return com.ruoyi.common.core.web.page.TableDataInfo
     * @author pengyu
     * @date 2023/2/22 14:45
     **/
    @RequestMapping("/retaion/selectList")
    @LogFeignCall
    public TableDataInfo selectList();

    /**
     * 手机端获取版本
     *
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/22 14:46
     **/
    @PostMapping("/version/getVersionInfo")
    @LogFeignCall
    public AjaxResult getVersionInfo(@RequestParam("packageName") String packageName);

    /**
     * 手机端通知列表
     *
     * @return com.ruoyi.common.core.web.page.TableDataInfo
     * @author pengyu
     * @date 2023/2/22 13:05
     **/
    /*@GetMapping("/notice/noticlist")
    public TableDataInfo noticlist(@RequestParam(value = "pageNum") Integer pageNum, @RequestParam(value = "pageSize") Integer pageSize);*/
    @GetMapping("/notice/listNoticeByDeptId")
    @LogFeignCall
    public AjaxResult noticlist(@RequestParam(value = "pageNum") Integer pageNum, @RequestParam(value = "pageSize") Integer pageSize);

    //根据通知公告编号获取详细信息（App）
    @RequestMapping("/notice/getInfoApp")
    @LogFeignCall
    public AjaxResult getInfoApp(@RequestParam(value = "noticeId") Long noticeId);

    //根据参数键名查询参数值
    @GetMapping(value = "/config/configKey/{configKey}")
    @LogFeignCall
    public AjaxResult getConfigKey(@PathVariable(value = "configKey") String configKey);

    //根据用户编号获取详细信息远程接口
    @RequestMapping(value = "/user/selectById/{userId}")
    @LogFeignCall
    public R<SysUser> selectById(@PathVariable("userId") Long userId);

    //根据部门编号获取详细信息
    @RequestMapping("/dept/selectDeptById/{deptId}")
    @LogFeignCall
    public R<SysDept> selectDeptById(@PathVariable("deptId") Long deptId);

    //获取全部部门
    @GetMapping("/dept/getDeptListAll")
    @LogFeignCall
    R<List<SysDept>> treeselectAll();

    /**
     * 根据参数键名查询参数值
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 14:30
     */
    @RequestMapping("/config/selectConfigKey/{configKey}")
    @LogFeignCall
    public R<String> selectConfigKey(@PathVariable("configKey") String configKey);

    /**
     * 根据多个参数键名查询多个参数键值MAP
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 14:31
     */
    @PostMapping(value = "/config/getConfigMap")
    @LogFeignCall
    R<Map<String, String>> remotegetConfigMap(@RequestParam("keys") List<String> keys);

    /**
     * 获取当前用户信息
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 8:43
     */
    @GetMapping("/user/info/{username}")
    @LogFeignCall
    public R<LoginUser> getUserInfo(@PathVariable("username") String username, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);


    /**
     * 修改用户的极光设备码
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 8:43
     */
    @GetMapping("/user/updateUserJg/{userName}/{deviceid}")
    @LogFeignCall
    public R updateUserJg(@PathVariable("userName") String userName, @PathVariable("deviceid") String deviceid);

    /**
     * 手机端新增考勤打卡
     *
     * @param sys
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/21 16:23
     */
    @PutMapping("/sysAttendance/addAttendance")
    @LogFeignCall
    public AjaxResult addAttendance(@RequestBody SysAttendance sys);

    /**
     * 手机端查询考勤打卡
     *
     * @param userId
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/21 16:23
     */
    @GetMapping("/sysAttendance/getAttendance/{userId}")
    @LogFeignCall
    public AjaxResult getAttendance(@PathVariable("userId") Long userId);

    /**
     * 通过用户名查询用户
     *
     * @param userName
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/21 16:23
     */
    @GetMapping("/sysutils/deptselector")
    @LogFeignCall
    public AjaxResult deptselector(@RequestParam("userName") String userName);

    /**
     * 获取所有组织机构
     *
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/2/21 16:23
     */
    @GetMapping("/dept/appList")
    @LogFeignCall
    public AjaxResult getDeptList(@RequestParam("deptName") String deptName);

    /**
     * @param sysMenuEventType
     * @Description: 通过menu_id查询事件类型
     * @return: AjaxResult
     */
    @PostMapping(value = "/menuEventType/selectByMenuId")
    @LogFeignCall
    R<List<SysMenuEventType>> selectByMenuId(@RequestBody SysMenuEventType sysMenuEventType);

    /**
     * 获取可视化菜单信息
     *
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/5/26 16:23
     */
    @GetMapping("/user/selectRoleMenuVisuTreest")
    @LogFeignCall
    public AjaxResult selectRoleMenuVisuTreest();

    @GetMapping("/menuEventType/selectByMenuIds/{ids}")
    @LogFeignCall
    R<List<SysMenuEventType>> selectByMenuIds(@PathVariable("ids") String[] ids);

    @GetMapping("/user/selectUserWithPostByDeptId")
    @LogFeignCall
    R<List<SysUserSystem>> selectUserWithPostByDeptId(@RequestParam("deptId") Long deptId);

    @GetMapping("/hwMeeting/joinConferences/{eventId}/{meetingSubject}/{userName}")
    @LogFeignCall
    public AjaxResult joinConferences(@PathVariable("eventId") String eventId, @PathVariable("meetingSubject") String meetingSubject, @PathVariable("userName") String userName);

    @GetMapping("/menuApp/getAppChildrenMenuOrButtonByParentId")
    @LogFeignCall
    AjaxResult getAppChildrenMenuOrButtonByParentId(@RequestParam("parentId") String parentId,@RequestParam("menuType") String menuType);

    @GetMapping("/dict/data/type/{dictType}")
    @LogFeignCall
    AjaxResult getSortByType(@PathVariable("dictType") String dictType);

    @GetMapping("/menuApp/selectMenuListByParentIdAndRoleId/{parentId}")
    @LogFeignCall
    AjaxResult getMenuListByParentId(@PathVariable("parentId") String parentId);

    @PostMapping("/user/userFeginlist")
    @LogFeignCall
    R<List<SysUser>> getUserList(@RequestBody SysUser sysUser);

    @PostMapping("/user/userFeginlistWithPage")
    @LogFeignCall
    List<SysUser> getUserListByPage(@RequestBody SysUser sysUser);

    @GetMapping(value = "/dept/userDeptSelectIncludeChildren/{deptId}")
    @LogFeignCall
    AjaxResult userDeptSelectIncludeChildren(@PathVariable("deptId") String deptId);

    @GetMapping("/dept/userDeptSelect")
    @LogFeignCall
    AjaxResult getUserDeptSelect();

    @GetMapping("/dept/getChildren/{deptId}/{postId}")
    @LogFeignCall
    AjaxResult getChildren(@PathVariable("deptId") String deptId, @PathVariable("postId") String postId);

    @GetMapping("/dict/data/internetOfThings/{dictType}")
    @LogFeignCall
    AjaxResult getSortByTypeAndCount(@PathVariable("dictType") String dictType);

    @PostMapping("/dept/getDeptsByDeptType")
    @LogFeignCall
    AjaxResult getDeptsByDeptType(@RequestBody SysDept sysDept);

    @GetMapping("/user/forceUpdatePwd/{username}")
    AjaxResult forceUpdatePwd(@PathVariable("username")String username);

    @PutMapping("/user/profile/updateAppPwd")
    AjaxResult updatPwd(@RequestBody AppUpPwd appUpPwd);
}
