package com.sooka.sponest.mobile.system.camera.controller;

import com.alibaba.fastjson.JSON;
import com.ruoyi.common.core.constant.HttpStatus;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.sooka.sponest.mobile.base.controller.AppBaseController;
import com.sooka.sponest.mobile.remoteapi.RemoteMonitorBaseService;
import com.sooka.sponest.mobile.remoteapi.RemoteSystemBaseService;
import com.sooka.sponest.mobile.system.camera.domain.*;
import com.sooka.sponest.mobile.system.camera.service.AppCameraService;
import com.sooka.sponest.mobile.utils.PictureReplaceAll;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections4.MapUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping("AppCameraController")
public class AppCameraController extends AppBaseController {

    @Resource
    AppCameraService appCameraService;
    @Resource
    RemoteMonitorBaseService remoteMonitorBaseService;
    @Resource
    RemoteSystemBaseService remoteSystemBaseService;

    /**
     * 附近摄像头列表
     *
     * @return AjaxResult
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 10:47
     */
    @ApiOperation(value = "摄像头列表", notes = "摄像头列表")
    @PostMapping("nearCamera")
    public AjaxResult nearCamera(@RequestBody AppCameraVO appCameraVO) {
        startPage();
        return appCameraService.nearCamera(appCameraVO);
    }



    /**
     * 附近摄像头列表
     *
     * @return AjaxResult
     * @Version 1.0
     */
    @ApiOperation(value = "摄像头列表", notes = "摄像头列表")
    @PostMapping("newNearCamera")
    public AjaxResult newNearCamera(@RequestBody AppCameraVO appCameraVO) {
        startPage();
        return appCameraService.newNearCamera(appCameraVO);
    }

    /**
     * 所有摄像头列表
     *
     * @return
     * @Version 1.0
     * @author jiangbo
     * @since
     */
    @ApiOperation(value = "摄像头列表", notes = "摄像头列表")
    @GetMapping("listCamera")
    public AjaxResult listCamera(CentermonitorTCamera centermonitorTCamera) {
        return appCameraService.listCamera(centermonitorTCamera);
    }

    /**
     * 摄像头详情
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/23 10:47
     */
    @ApiOperation(value = "摄像头详情", notes = "摄像头详情")
    @PostMapping("detail")
    public AjaxResult detail(@RequestBody AppCameraVO appCameraVO) {
        AppCameraListBO detail = appCameraService.detail(appCameraVO);
        return AjaxResult.success(detail);
    }

    /**
     * 动态获取大华摄像头登录参数
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/23 10:47
     */
    @ApiOperation(value = "动态获取大华摄像头登录参数", notes = "动态获取大华摄像头登录参数")
    @GetMapping("getDahuaVideoServer")
    public AjaxResult getDahuaVideoServer() {
        return appCameraService.getDahuaVideoServer();
    }


    /**************************************************市局领导页面接口——开始****************************************************/

    /**
     * 手机端领导页面查看所有摄像头
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/4/24 14:22
     */
    @PostMapping("/selectCameraByDeptId")
    public AjaxResult selectCameraByDeptId(@RequestBody VisuForestMonitorCenterVO vo) {
        List<LinkedHashMap> appCloudCameraBOS = appCameraService.selectCameraByDeptId(vo);
        return AjaxResult.success(appCloudCameraBOS);
    }

    /**
     * 手机端领导页面查看所有大喇叭
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/4/24 14:22
     */
    @GetMapping("/getDlblistBydeptId")
    public AjaxResult getDlblistBydeptId(Long deptId, String broadcastUse, String name) {
        return appCameraService.getDlblistBydeptId(deptId, broadcastUse, name);
    }

    /**
     * 手机端领导页面查看所有传感器
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/4/24 14:22
     */
    @GetMapping("/getSensorListByDeptId")
    public AjaxResult getSensorListByDeptId(Long deptId) {
        return appCameraService.getSensorListByDeptId(deptId);
    }

    /**************************************************市局领导页面接口——结束****************************************************/

    /**
     * 手机端获取事件详情火点周边摄像头信息
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/5/6 14:57
     */
    @GetMapping("findCameraByEventCoordinate")
    public AjaxResult findCameraByEventCoordinate(String longitude, String latitude, String type) {
        return remoteMonitorBaseService.findCameraByEventCoordinate(longitude, latitude, type);
    }

    /**
     * 传入经纬度和摄像头集合使摄像头转到固定点位
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/4/19 9:23
     */
    @ApiOperation(value = "火点摄像头联动接口", notes = "火点摄像头联动接口")
    @PostMapping("rotation")
    public AjaxResult rotation(@RequestBody RotationVo rotationVo) {
        return remoteMonitorBaseService.rotation(rotationVo.getLng(), rotationVo.getLat(), rotationVo.getList());
    }

    /**
     * 获取传感器信息
     *
     * @param centermonitorTMonitoringDevice
     * @return com.ruoyi.common.core.web.domain.AjaxResult
     * @author pengyu
     * @date 2023/5/31 15:52
     **/
    @ApiOperation(value = "获取传感器信息", notes = "获取传感器信息")
    @PostMapping("getMonitorDeviceAndDataList")
    public AjaxResult getMonitorDeviceAndDataList(@RequestBody CentermonitorTMonitoringDevice centermonitorTMonitoringDevice) {
        Map<String, Object> map = new HashMap<>();
        String appUrl = remoteSystemBaseService.selectConfigKey("appUrl").getData();
        List<LinkedHashMap> result = new ArrayList<>();
        boolean other = "other".equals(centermonitorTMonitoringDevice.getRequestType());//普通人员
        boolean leader = "leader".equals(centermonitorTMonitoringDevice.getRequestType());//领导页面
        if (other || (leader && !"".equals(centermonitorTMonitoringDevice.getDeviceType()))) {
            AjaxResult monitorDeviceAndDataList = remoteMonitorBaseService.getMonitorDeviceAndDataList(centermonitorTMonitoringDevice.getDeptId(), centermonitorTMonitoringDevice.getDeviceType(), centermonitorTMonitoringDevice.getDeviceName());
            result = (List<LinkedHashMap>) monitorDeviceAndDataList.get("data");
            for (LinkedHashMap maps : result) {
                if (maps.containsKey("data")) {
                    HashMap data = (HashMap) maps.get("data");
                    if (data != null && data.containsKey("taggingImgUrl")) {
                        data.put("taggingImgUrl", appUrl + data.get("taggingImgUrl").toString());
                    }
                    if (data != null && data.containsKey("oldTaggingImgUrl")) {
                        data.put("oldTaggingImgUrl", appUrl + data.get("oldTaggingImgUrl").toString());
                    }
                }
            }
        }
        map.put("sensors", result);
        result = new ArrayList<>();
        VisuForestMonitorCenterVO vo = new VisuForestMonitorCenterVO();
        vo.setDeptId(Long.valueOf(centermonitorTMonitoringDevice.getDeptId()));
        vo.setType(centermonitorTMonitoringDevice.getType());
        vo.setCameraName(centermonitorTMonitoringDevice.getDeviceName());
        if (other) {
            //cameraUse = 1;
            vo.setCameraUse("1");
            result = (List<LinkedHashMap>) remoteMonitorBaseService.selectCameraByDeptId(vo).get("data");
        } else if (leader && !"".equals(centermonitorTMonitoringDevice.getCameraUse())) {
            vo.setCameraUse(centermonitorTMonitoringDevice.getCameraUse());
            result = (List<LinkedHashMap>) remoteMonitorBaseService.selectCameraByDeptId(vo).get("data");
        }

        map.put("waters", result);
        return AjaxResult.success(map);
    }

    /**
     * 获取全部摄像头列表
     *
     * @param camera
     * @return
     */
    @PostMapping("remoteList")
    public AjaxResult remoteList(@RequestBody CentermonitorTCamera camera) {
        R<List<CentermonitorTCamera>> listR = remoteMonitorBaseService.remoteList(camera);
        if (HttpStatus.SUCCESS == listR.getCode()) {
            return AjaxResult.success(listR.getData());
        } else {
            return AjaxResult.error(listR.getMsg());
        }
    }

    /**
     * 根据类型查询分类
     * camera_use 视联网
     * device_type 物联网
     * broadcast_use 云广播
     * @return
     */
    @GetMapping("/getSortByType")
    public AjaxResult getSortByType(String dictType) {
        if ("device_type".equals(dictType)) {
            AjaxResult result = remoteSystemBaseService.getSortByType(dictType);
            List<Map<String, Object>> data = (List<Map<String, Object>>) result.get("data");
            List<Map<String, Object>> cameraUse = (List<Map<String, Object>>) remoteSystemBaseService.getSortByType("camera_use").get("data");
            data.addAll(screenSort(cameraUse));
            return result;
        } else {
            return remoteSystemBaseService.getSortByType(dictType);
        }
    }

    /**
     * 根据类型查询分类并统计数量
     * camera_use 视联网
     * device_type 物联网
     * broadcast_use 云广播
     * @return
     */
    @GetMapping("/getSortByTypeAndCount")
    public AjaxResult getSortByTypeAndCount(@RequestParam("dictType") String dictType) {
        if ("device_type".equals(dictType)) {
            AjaxResult result = remoteSystemBaseService.getSortByTypeAndCount(dictType);
            List<Map<String, Object>> data = (List<Map<String, Object>>) result.get("data");
            List<Map<String, Object>> cameraUse = (List<Map<String, Object>>) remoteSystemBaseService.getSortByTypeAndCount("camera_use").get("data");
            data.addAll(screenSort(cameraUse));
            return result;
        } else {
            return remoteSystemBaseService.getSortByTypeAndCount(dictType);
        }
    }

    public List<Map<String, Object>> screenSort(List<Map<String, Object>> data) {
        List<Map<String, Object>> result = data.stream()
                .filter(datum -> {
                    String dictValue = datum.get("dictValue").toString();
                    return !Arrays.asList("2").contains(dictValue);
                })
                .collect(Collectors.toList());
        return result;
    }

    /**
     * 查询视联网详情
     *
     * @param id 视联网设备ID
     * @return AjaxResult
     */
    @GetMapping("/getCameraById")
    public AjaxResult getCameraByCameraId(@RequestParam("id") String id) {
        return replacePictures(remoteMonitorBaseService.selectByCameraId(id), "cameraImagesList");
    }

    /**
     * 查询物联网详情
     *
     * @param id
     * @return
     */
    @GetMapping("getDeviceById")
    public AjaxResult getDeviceById(@RequestParam("id") String id) {
        AjaxResult ajaxResult = remoteMonitorBaseService.selectByDeviceId(id);
        String oldIp = SpringUtils.getBean(RemoteSystemBaseService.class).selectConfigKey("fileUrl").getData();
        String newIp = SpringUtils.getBean(RemoteSystemBaseService.class).selectConfigKey("appUrl").getData();
        Map<String, Object> data = (Map<String, Object>) ajaxResult.get("data");
        Map<String, Object> picture = (Map<String, Object>) data.get("sensorDetectionList");
        for (String key : picture.keySet()) {
            if (key.contains("图片")) {
                picture.put(key, MapUtils.getString(picture, key).replaceAll(oldIp, newIp));
            }
        }
        ajaxResult.put("data", data);
        return replacePictures(ajaxResult, "deviceImagesList");
    }

    /**
     * 查询云广播详情
     *
     * @param id
     * @return
     */
    @GetMapping("getBroadcastById")
    public AjaxResult getBroadcastById(@RequestParam("id") String id) {
        return replacePictures(remoteMonitorBaseService.selectByBroadcastId(id), "broadcastImagesList");
    }

    private static AjaxResult replacePictures(AjaxResult ajaxResult, String type) {
        if ("200".equals(ajaxResult.get("code").toString())) {
            Map<String, Object> data = (Map<String, Object>) ajaxResult.get("data");
            List<String> dataList = (List<String>) data.get(type);
            data.put(type, PictureReplaceAll.replaceAllPictureUrl2(dataList, "url"));
            return AjaxResult.success(data);
        } else {
            return ajaxResult;
        }
    }

}
