package com.sooka.sponest.mobile.system.camera.service.impl;

import com.ruoyi.common.core.web.domain.AjaxResult;
import com.sooka.sponest.mobile.remoteapi.RemoteMonitorBaseService;
import com.sooka.sponest.mobile.system.camera.domain.*;
import com.sooka.sponest.mobile.system.camera.service.AppCameraService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class AppCameraServiceImpl implements AppCameraService {

    @Autowired
    RemoteMonitorBaseService remoteMonitorBaseService;

    /**
     * 附近摄像头列表
     *
     * @return
     * @Version 1.0
     * @author wang_xy
     * @since 2023/2/22 10:47
     */
    @Override
    public AjaxResult nearCamera(AppCameraVO appCameraVO) {
        String longitude = appCameraVO.getLongitude();
        String latitude = appCameraVO.getLatitude();
        List list = (ArrayList) remoteMonitorBaseService.selectFjsxt(longitude, latitude).get("data");
        Map<String, Object> objectMap = new HashMap<>();
        objectMap.put("total", list.size());
        objectMap.put("list", list);
        return AjaxResult.success(objectMap);
    }


    /**
     * 附近摄像头列表
     *
     * @return
     * @Version 1.0
     */
    @Override
    public AjaxResult newNearCamera(AppCameraVO appCameraVO) {
        String longitude = appCameraVO.getLongitude();
        String latitude = appCameraVO.getLatitude();
        String type = appCameraVO.getType();
        List list = (ArrayList) remoteMonitorBaseService.findCameraByEventCoordinate(longitude, latitude,type).get("data");
        return AjaxResult.success(list);
    }

    /**
     * 所有摄像头列表
     *
     * @return
     * @Version 1.0
     * @author jiangbo
     */
    @Override
    public AjaxResult listCamera(CentermonitorTCamera centermonitorTCamera) {
//        List list = (ArrayList) remoteMonitorBaseService.cameraList(centermonitorTCamera).get("data");
//        return list;
//        List rows = remoteMonitorBaseService.cameraList(centermonitorTCamera).getRows();
//        return rows;
        return remoteMonitorBaseService.cameraList(centermonitorTCamera);
    }

    @Override
    public AppCameraListBO detail(AppCameraVO appCameraVO) {
        String cameraId = appCameraVO.getCameraId();
        AppCameraDetailsBO appCameraDetailsBO = remoteMonitorBaseService.getInfo(cameraId).getData();
        List<AppCameraChannelBO> appCameraChannelBOS = remoteMonitorBaseService.selectCameraChannelList(cameraId).getData();
        AppCameraListBO appCameraListBO = new AppCameraListBO();
        appCameraListBO.setAppCameraDetailsBO(appCameraDetailsBO);
        appCameraListBO.setAppCameraChannelBOS(appCameraChannelBOS);

        String channelCode = "";
        for (AppCameraChannelBO abo : appCameraChannelBOS) {
            if ("2".equals(abo.getChannelType())) {
                channelCode = abo.getChannelCode();
                break;
            }
        }
//        if(!"1".equals(appCameraDetailsBO.getCameraFactory())){
//            AjaxResult ar = remoteMonitorBaseService.getCameraPreviewURL(channelCode);
//            String videoStream = JSONObject.parseObject(ar.get("msg").toString()).getJSONObject("data").getString("url");
//            appCameraListBO.setVideoStream(videoStream);
//            return appCameraListBO;
//        }
        return appCameraListBO;
    }

    @Override
    public AjaxResult getDahuaVideoServer() {
        return remoteMonitorBaseService.getDahuaVideoServer();
    }

    @Override
    public List<LinkedHashMap> selectCameraByDeptId(VisuForestMonitorCenterVO vo) {
        return (List<LinkedHashMap>) remoteMonitorBaseService.selectCameraByDeptId(vo).get("data");
    }

    @Override
    public AjaxResult getDlblistBydeptId(Long deptId, String broadcastUse, String name) {
        String type = "1, 2, 3, 4, 5, 6, 7, 8";
        return remoteMonitorBaseService.getDlblistBydeptId(deptId, broadcastUse, type, name);
    }

    @Override
    public AjaxResult getSensorListByDeptId(Long deptId) {
        return remoteMonitorBaseService.getSensorListByDeptId(deptId);
    }

    @Override
    public AjaxResult selectCameraByIds(Map<String, Object> info) {
        List<String> deviceList = new ArrayList<>();
        if (null != info.get("deviceList")) {
            deviceList = (List<String>) info.get("deviceList");
        } else if (null != info.get("cameraList")) {
            deviceList = (List<String>) info.get("cameraList");
        } else {
            info.put("errorMsg", "未找到绑定的设备编号");
        }
        if (null != deviceList && !deviceList.isEmpty()) {
            StringBuilder ids = new StringBuilder();
            deviceList.forEach(s -> ids.append(s).append(","));
            ids.deleteCharAt(ids.length() - 1);
            AjaxResult ajaxResult = remoteMonitorBaseService.selectIdTCameraByIds(ids.toString().split(","));
            info.put("deviceEntityList", ajaxResult.get("data"));
            //增加判断，防止ajaxResult.get("data")为null时，不知道为空原因
            if (!"200".equals(ajaxResult.get("code").toString())) {
                info.put("deviceEntityListMsg", ajaxResult.get("msg"));
            }
        } else {
            info.put("deviceEntityList", new ArrayList<>());
        }
        return AjaxResult.success(info);
    }
}
