package com.sooka.sponest.mobile.system.login.controller;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.redis.service.RedisService;
import com.sooka.sponest.mobile.system.login.domain.AppLoginVO;
import com.sooka.sponest.mobile.system.login.domain.AppUpPwd;
import com.sooka.sponest.mobile.system.login.domain.SysMenuApp;
import com.sooka.sponest.mobile.system.login.service.AppLoginService;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

@RestController
@RequestMapping("AppLoginController")
public class AppLoginController {

    @Resource
    AppLoginService appLoginService;
    @Resource
    RedisService redisService;

    /**
     * 手机端登录接口
     * @Version 1.0
     * @return
     * @author wang_xy
     * @since 2023/2/22 8:43
     */
    @ApiOperation(value = "登录", notes = "登录")
    @PostMapping("login")
    public AjaxResult login(@RequestBody AppLoginVO appLoginVO, HttpServletRequest request){
        String privateKey = redisService.getCacheObject(appLoginVO.getSessionId());
        String sessionId = request.getSession().getId();
        redisService.setCacheObject(sessionId, privateKey);
        AjaxResult ajaxResult = appLoginService.login(appLoginVO);
        return ajaxResult;
    }

    /**
     * 手机端获取秘钥
     * @Version 1.0
     * @return
     * @author wang_xy
     * @since 2023/2/22 8:43
     */
    @ApiOperation(value = "获取秘钥", notes = "获取秘钥")
    @PostMapping("getPrivateKey")
    public AjaxResult getPrivateKey(HttpServletRequest request){
        AjaxResult ajaxResult = appLoginService.getPrivateKey(request);
        return ajaxResult;
    }

    /**
     * 通过用户名查询用户
     * @Version 1.0
     * @return
     * @author wang_xy
     * @since 2023/2/22 8:43
     */
    @ApiOperation(value = "通过用户名查询用户", notes = "通过用户名查询用户")
    @GetMapping("deptselector")
    public AjaxResult deptselector(String userName){
        AjaxResult ajaxResult = appLoginService.deptselector(userName);
        return ajaxResult;
    }

    /**
     * 获取可视化菜单信息
     *
     * @return 用户信息
     */
    @ApiOperation(value = "获取可视化菜单信息", notes = "获取可视化菜单信息")
    @GetMapping("selectRoleMenuVisuTreest")
    public AjaxResult selectRoleMenuVisuTreest(){
        AjaxResult ajaxResult = appLoginService.selectRoleMenuVisuTreest();
        if(!ajaxResult.get("code").equals(200)){
            return AjaxResult.error("查询失败");
        }else{
            return AjaxResult.success("查询成功",ajaxResult.get("list"));
        }
    }

    /**
     * 获取二级菜单及权限
     */
    @GetMapping("/getAppChildrenMenuOrButtonByParentId")
    public AjaxResult getAppChildrenMenuOrButtonByParentId(SysMenuApp sysMenuApp){
        AjaxResult ajaxResult = appLoginService.getAppChildrenMenuOrButtonByParentId(sysMenuApp);
        return ajaxResult;
    }

    @PostMapping("/updatePwd")
    public AjaxResult updatePwd(@RequestBody AppUpPwd appUpPwd){
        return appLoginService.updatePwd(appUpPwd);
    }

}
