package com.sooka.sponest.mobile.system.login.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.constant.SecurityConstants;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.redis.service.RedisService;
import com.ruoyi.system.api.model.LoginUser;
import com.sooka.sponest.mobile.remoteapi.RemoteAuthService;
import com.sooka.sponest.mobile.remoteapi.RemoteSystemBaseService;
import com.sooka.sponest.mobile.remoteapi.domain.LoginBody;
import com.sooka.sponest.mobile.system.login.domain.AppLoginBO;
import com.sooka.sponest.mobile.system.login.domain.AppLoginVO;
import com.sooka.sponest.mobile.system.login.domain.AppUpPwd;
import com.sooka.sponest.mobile.system.login.domain.SysMenuApp;
import com.sooka.sponest.mobile.system.login.service.AppLoginService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

@Service
public class AppLoginServiceImpl implements AppLoginService {
    private static final Logger log = LoggerFactory.getLogger(AppLoginServiceImpl.class);


    @Resource
    RemoteAuthService remoteAuthService;
    @Resource
    RemoteSystemBaseService remoteSystemBaseService;
    @Resource
    RedisService redisService;

    /**
     * 手机端登录接口
     * @Version 1.0
     * @return
     * @author wang_xy
     * @since 2023/2/22 8:43
     */
    @Override
    public AjaxResult login(AppLoginVO appLoginVO) {
        R<?> map = null;
        try{
            // 查询用户信息
            R<LoginUser> userResult = remoteSystemBaseService.getUserInfo(appLoginVO.getUsername(), SecurityConstants.INNER);

            if (StringUtils.isNull(userResult) || StringUtils.isNull(userResult.getData())) {
                return AjaxResult.error(R.FAIL,"登录用户不存在");
            }
            if(StringUtils.isNotEmpty(appLoginVO.getDeviceid())){
                remoteSystemBaseService.updateUserJg(appLoginVO.getUsername(),appLoginVO.getDeviceid());
            }
            //
            Boolean flag = Boolean.parseBoolean(remoteSystemBaseService.forceUpdatePwd(appLoginVO.getUsername()).get("data").toString());
            LoginBody loginBody = new LoginBody();
            loginBody.setUsername(appLoginVO.getUsername());
            loginBody.setPassword(appLoginVO.getPassword());
            loginBody.setSessionId(appLoginVO.getSessionId());
            map = remoteAuthService.loginApp(loginBody);
            if(map.getCode() == 200){
                LinkedHashMap linkedHashMap = (LinkedHashMap) map.getData();
                String json = JSON.toJSONString(linkedHashMap);
                AppLoginBO bo = JSON.parseObject(json, AppLoginBO.class);
                ArrayList deptList = (ArrayList)((LinkedHashMap) remoteSystemBaseService.deptselector(bo.getUserinfo().getUsername()).get("data")).get("depts");
                bo.setDeptList(deptList);
                bo.setUpdatePwd(flag);
                return AjaxResult.success(bo);
            }else{
                return AjaxResult.error(map.getCode(),map.getMsg());
            }
        }catch (Exception e){
            log.error(e.getMessage());
            return AjaxResult.error(R.FAIL,"登录失败");
        }
    }

    /**
     * 手机端获取秘钥
     * @Version 1.0
     * @return
     * @author wang_xy
     * @since 2023/2/22 8:43
     */
    @Override
    public AjaxResult getPrivateKey(HttpServletRequest request) {
        String sessionId = request.getSession().getId();
        AjaxResult ajaxResult = remoteAuthService.getSecretKeys(sessionId);
        String publicKey = ajaxResult.get("data").toString();
        Map data = new HashMap();
        data.put("sessionId", sessionId);
        data.put("publicKey", publicKey);
        ajaxResult.put("data", data);
        return ajaxResult;
    }


    @Override
    public AjaxResult deptselector(String userName) {
        return remoteSystemBaseService.deptselector(userName);
    }
    @Override
    public AjaxResult selectRoleMenuVisuTreest() {
        return remoteSystemBaseService.selectRoleMenuVisuTreest();
    }

    @Override
    public AjaxResult getAppChildrenMenuOrButtonByParentId(SysMenuApp sysMenuApp) {
        return remoteSystemBaseService.getAppChildrenMenuOrButtonByParentId(sysMenuApp.getParentId(),sysMenuApp.getMenuType());
    }

    @Override
    public AjaxResult updatePwd(AppUpPwd appUpPwd){
        return remoteSystemBaseService.updatPwd(appUpPwd);
    }
}
